#ifndef DIALOGSEARCH_H
#define DIALOGSEARCH_H

#include <QDialog>
#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QDateEdit>
#include <QtGui/QDialog>
#include <QtGui/QDialogButtonBox>
#include <QtGui/QHBoxLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QPushButton>
#include <QtGui/QSpacerItem>
#include <QtGui/QVBoxLayout>

#include <QtMaemo5/QMaemo5ValueButton>
#include <QtMaemo5/QMaemo5TimePickSelector>
#include <QtMaemo5/QMaemo5DatePickSelector>

/*namespace Ui {
    class DialogSearch;
}*/

class DialogSearch : public QDialog {
    Q_OBJECT
public:
    DialogSearch(QWidget *parent = 0);
    ~DialogSearch();
    int totalHours(bool &ok);
protected:
    void changeEvent(QEvent *e);

private:
    //Ui::DialogSearch *ui;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    //QLabel *label;
    QMaemo5ValueButton *pushButtonStart;
    QDateEdit *dateEditStart;
    QHBoxLayout *horizontalLayout_2;
    //QLabel *label_2;
    QMaemo5ValueButton *pushButtonEnd;
    //QDateEdit *dateEditEnd;
    QSpacerItem *horizontalSpacer;
    QDialogButtonBox *buttonBox;
public slots:

    void accept();
};

#endif // DIALOGSEARCH_H
